@@ -42,7 +42,7 @@ use overload
 # CVS ID: $Id$
 
 use vars qw/ $VERSION /;
-$VERSION = '0.05';
+$VERSION = '0.06';
 
 # hash of allowed lower-cased constructor keys with
 # corresponding accessor method
@@ -512,8 +512,10 @@ sub contains {
   } else {
     # normal interval
     if (defined $max and defined $min) {
-      if ($max == $min) {
-	$contains = 1 if $value == $max;
+      if ($max == $min) { # need to include a bound
+	if ($self->inc_min || $self->inc_max) {
+	  $contains = 1 if $value == $max;
+	}
       } elsif ($self->pos_def && $value < 0) {
 	$contains = 0;
       } elsif ($self->inc_max && $self->inc_min) {
@@ -828,6 +830,23 @@ sub intersection {
 
   # Modify object if we have new values
   if (defined $outmax or defined $outmin) {
+    # Need to check the inc_min and inc_max settings
+    my $inc_max = $self->_checkinc( $outmax, $max1, $max2,
+				    $self->inc_max, $new->inc_max );
+    my $inc_min = $self->_checkinc( $outmin, $min1, $min2,
+				    $self->inc_min, $new->inc_min );
+
+    # Abort if the min and max are the same and we
+    # are not including the bounds in the interval
+    if (defined $outmax && defined $outmin &&
+	$outmax == $outmin &&
+	(!$inc_max || !$inc_min)
+       ) {
+      return 0;
+    }
+
+    $self->inc_min( $inc_min );
+    $self->inc_max( $inc_max );
     $self->max($outmax);
     $self->min($outmin);
     return 1;
@@ -837,6 +856,31 @@ sub intersection {
 
 }
 
+# Given
+sub _checkinc {
+  my $self = shift;
+  my $newval = shift;
+  my $ref1 = shift;
+  my $ref2 = shift;
+  my $inc1 = shift;
+  my $inc2 = shift;
+
+  my $inc_val = $inc1;
+  if (defined $newval) {
+    if (defined $ref1 && $ref1 == $newval &&
+	defined $ref2 && $ref2 == $newval) {
+      # value comes from both so we want the least
+      # inclusive inc_max value
+      $inc_val = 0 if (!$inc1 || !$inc2);
+    } elsif (defined $ref2 && $ref2 == $newval) {
+      # this value comes from ref2 so we copy
+      # inc from #2
+      $inc_val = $inc2;
+    }
+  }
+  return $inc_val;
+}
+
 sub _formaterr {
   my ($min1, $max1, $min2, $max2) = @_;
   return "Comparing : (".
@@ -857,7 +901,7 @@ The default interval is not inclusive of the bounds.
 
 =head1 COPYRIGHT
 
-Copyright (C) 2009 Science and Technology Facilities Council.
+Copyright (C) 2009-2011 Science and Technology Facilities Council.
 Copyright (C) 2002-2005 Particle Physics and Astronomy Research Council.
 All Rights Reserved.
 
